package com.energy.online.data;

// 新增Spring Boot相关导入

import com.energy.online.data.dto.BaseConfig;
import com.energy.online.data.dto.Line;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import wei.yigulu.iec104.apdumodel.Apdu;
import wei.yigulu.iec104.apdumodel.Asdu;
import wei.yigulu.iec104.asdudataframe.PulseTotalSummonType;
import wei.yigulu.iec104.nettyconfig.Iec104MasterBuilder;
import wei.yigulu.iec104.util.SendDataFrameHelper;

import javax.annotation.PostConstruct;

@SpringBootApplication
@EnableAsync
@EnableScheduling
public class OnlineDataMain {

    @Autowired
    private BaseConfig baseConfig;

    @PostConstruct
    public void init() {
        Line line = baseConfig.getLine();
        runDeviceConnection(line);
    }

    public static Iec104MasterBuilder master;

    private void runDeviceConnection(Line line) {
        try {
            master = new Iec104MasterBuilder(line.getIp(), line.getPort());
            master.createByUnBlock();
            System.out.println("++++++++++++++++++++++++++++++++");
            Thread.sleep(3000L);
            SendDataFrameHelper.sendTotalSummonFrame(master.getFuture().channel(), line.getCoa(), 6, master.getLog());
            Thread.sleep(5000L);
            System.out.println("---------------------------------------");
            PulseTotalSummonType pulseTotalSummonType = new PulseTotalSummonType();
            Asdu asdu = pulseTotalSummonType.generateBack();
            Apdu apdu = new Apdu();
            apdu.setAsdu(asdu);
            master.sendFrameToOpposite(apdu.encode());
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    public static void main(String[] args) {
        SpringApplication.run(OnlineDataMain.class, args);
    }

}
